==> dl.php?src=linea21_1_0.zip: linea21/contents/mod.php <==
<?php
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$complete_type=strtoupper($mod_inc);

$contents_object = new contents;

$mask_template=array_fill(1, 3, '');
$layer_tpl_1 = "style=\"display:block;\"";

if($type=='P') {
	$requete= SQL_getOnePublicationParts($id);
	$result=$sql_object->DBSelect($requete);
	$form_title=formatText($result[0]['publicon_title'],'2FIELD');
	$form_body=formatText($result[0]['publicon_body'],'2FIELD');
	$current_template=$result[0]['publicon_template'];
	$form_visual=$result[0]['publicon_photos_uri'];
	$reca_visual="<dl class=\"dl_mod\">\n";
	$reca_visual.="<dt>".$GLOBALS['lang']['contents']['visu1'].": </dt>\n";
	if(empty($result[0]['publicon_photos_uri'])) {
		$reca_visual.="<dd>".$GLOBALS['lang']['divers']['none']."</dd>\n";
		$reca_visual2=$GLOBALS['lang']['divers']['none'];
	} else {
		$complete_uri='../'.$result[0]['publicon_photos_uri'];
		list($width, $height, $type_img, $attr) = getimagesize($complete_uri);
		$reca_visual.='<dd>'.EnlargeImage($complete_uri)."</dd>\n";
		$reca_visual2=EnlargeImage($complete_uri);
	}
	$reca_visual.="</dl>\n";
	if(!isset($_POST['valider'])) $mask_template[$current_template]=' selected="selected"';
	if(!isset($_POST['valider']) && $result[0]['publicon_template']==3) $layer_tpl_1 = "style=\"display:none;\"";
	}
if($type=='W') {
	$requete= SQL_getOneWorkshopParts($id);
	$result=$sql_object->DBSelect($requete);
	$form_title=formatText($result[0]['workrepcon_title'], '2FIELD');
	$form_body=formatText($result[0]['workrepcon_body'], '2FIELD');
}



if(isset($_POST['enregistrer'])) {
	include_once('../class/system/class.upload.php');
	$upload_object= new upload;
	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$contents_object->ModifyContents($id, $data_table, $complete_type, $sql_object);
	if(isset($data_table[3])) $result_rename=$upload_object->Archivefile('../'.$data_table[3]);
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

if(isset($_POST['valider'])) {
	$table[0]=$_POST['part_title'];
	$table[1]=$_POST['part_body'];
	
	$integrity=$contents_object->CheckDataIntegrity($table,$type);
	
	if($type=='P') {
		$table[2]=$_POST['part_template'];
		$table[3]=isset($_FILES['visuel1']['name']) ? $_FILES['visuel1']['name'] : '' ;
		if(!is_string($integrity) && $_POST['current_template']==3 && ($_POST['part_template']==1 || $_POST['part_template']==2 ) && (!isset($_FILES['visuel1']) || $_FILES['visuel1']['name']=='' )) $integrity=$GLOBALS['lang']['contents']['no_visu1'];
			
	if(!is_string($integrity)) {
		if($_POST['part_template']!=3 && isset($_FILES['visuel1']['name']) && $_FILES['visuel1']['name']!='') {
			include_once('../class/system/class.upload.php');
			include_once('../class/system/class.image.php');
			$image_object = new image;
            $upload_object = new upload;
            $upload1 = $_FILES['visuel1'];
			$size_integrity=$upload_object->CheckMaxFile($upload1['size'], $contents_object->P_UPLOAD_MAX_MO);
			if(is_string($size_integrity)) $integrity=$size_integrity;
			$format_integrity=$upload_object->CheckExtImage($upload1['name']);
			if(is_string($format_integrity)) $integrity=$format_integrity;

			if(!is_string($integrity)) {
				$file_name=$id;
				$destination="../".$contents_object->P_URI_INPUT;
				$bdd_name=$file_name.".".$upload_object->GetExtension($upload1['name']);
				$final_name='temp_'.$bdd_name;
				$visual_link1=$destination.$final_name;
				$table[3]=$contents_object->P_URI_INPUT.$bdd_name;
				
				$result_upload=$upload_object->UploadFile($upload1, $final_name, $destination);
				
				// cration des thumbs
				$min_name=get_min_name($destination.$final_name);
				$image_object->ThumbCreate($destination.$final_name, $min_name , $contents_object->P_MAX_PHOTO_MIN_WIDTH);
				
				// on retaille l'original au besoin.
				if(PHOTO_RESIZE===true && ExcedMaxSize($destination.$final_name, $contents_object->P_MAX_PHOTO_MAX_WIDTH)) {
					$image_object->ThumbCreate($destination.$final_name, $destination.$final_name , $contents_object->P_MAX_PHOTO_MAX_WIDTH);
				}
				
				// prparation de l'affichage de la miniature
				$visual_link1=EnlargeImage($visual_link1);
				
			}
        } else {
			if($_POST['part_template']!=3) $table[3]=$result[0]['publicon_photos_uri'];
			else $table[3]='';
		}
		}
	}

	
	if(is_string($integrity)) {
		$text_format='2FIELD';
	} else {
		$text_format='2HTML';
	}
	$form_title=formatText($_POST['part_title'], $text_format);
	$form_body=formatText($_POST['part_body'], $text_format);
	if($type=='P') {
		$mask_template[$_POST['part_template']]=' selected="selected"';
		if($_POST['part_template']==3) $layer_tpl_1 = "style=\"display:none;\"";
	}
	
	$table=urlencode(serialize($table));
}

if($type=='P') {
	$requete= SQL_getPublicationTitle($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['publi_title'], '2HTML');
	$current_owner=$result[0]['publi_posted_by'];
	
	//////////// Check Droits utilisateur ////////////
	if (GetSessionElement('id')!=$current_owner && !IsSuperAdmin()) ReloadIndex('admin');
	///////////

	
	// select-box Templates
	$select_template="<select name=\"part_template\" id=\"part_template\" onchange=\"ShowFilesLayer(this.value, 'contents')\">\n";
	$select_template.="<option value=\"1\"".$mask_template[1].">".$contents_object->GetTemplateName(1)."</option>\n";
	$select_template.="<option value=\"2\"".$mask_template[2].">".$contents_object->GetTemplateName(2)."</option>\n";
	$select_template.="<option value=\"3\"".$mask_template[3].">".$contents_object->GetTemplateName(3)."</option>\n";
	$select_template.="</select>\n";
}
if($type=='W') {
	$requete= SQL_getWorkshopRepTitleAndGroup($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['workrep_title'].' ('.$result[0]['workshop_denomination'].').', '2HTML');
	$current_workshop_id=$result[0]['workrep_workshop_id'];
	
	//////////// Check Droits utilisateur ////////////
	if (!AuthUser4Workshop($current_workshop_id, $sql_object) && !IsSuperAdmin()) ReloadIndex('admin');
	///////////
	
}
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu'][$mod_inc]; ?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($GLOBALS['lang']['contents'][$mod_inc.'_type']." : ". $current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>

<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
		?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
			<h2><? echo formatTitleh2($current_title); ?></h2>
			<form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post" enctype="multipart/form-data">
				<p>
				<label for="part_title"><? echo $GLOBALS['lang']['contents']['title']; ?> : *</label>
				<input name="part_title" type="text" class="textfield" id="part_title" maxlength="200" value="<?php echo $form_title; ?>" />
				</p>
				<p>
				<label for="part_body"><? echo $GLOBALS['lang']['contents']['body']; ?> : *</label>
				<textarea id="part_body" name="part_body" class="largetextfield" <?php echo AREA_SETTINGS; ?>><?php echo $form_body; ?></textarea>
				</p>
				<p>
				<?php  if($type=='P') { ?>
				<label for="part_template" ><? echo $GLOBALS['lang']['contents']['template']; ?> : *</label>
				<?php echo $select_template; ?>
				</p>
				<?php echo $reca_visual; ?>
				<p id="layervisuel1" <?php echo $layer_tpl_1; ?>>
					<label for="visuel1"><?php echo $GLOBALS['lang']['contents']['visu1']; ?></label>
					<input name="visuel1" type="file" size="47" id="visuel1"  class="file" /><br /><br />
				</p>
				<?php } ?>
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<input name="current_template" type="hidden" value="<?php echo $current_template; ?>" id="current_template" />
				<?php echo cancel_button($cancel_link); ?>
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Rcapitulatif
} else	{

if($type=='P') {
	if($_POST['part_template']==3) {
		$display_visual=$GLOBALS['lang']['divers']['none'];
	} else {
		if(isset($visual_link1)) $display_visual=$visual_link1;
		else $display_visual=$reca_visual2;
	}
	$display_template_choice=$contents_object->GetTemplateName($_POST['part_template']);
}

?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
			<h2><? echo formatTitleh2($GLOBALS['lang']['recap']['title']); ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['contents']['title']."</dt>\n";
			echo "<dd>".$form_title."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['contents']['body']."</dt>\n";
			echo "<dd>".linkin_content($form_body)."</dd>\n";
			if($type=='P') {
				echo "<dt>".$GLOBALS['lang']['contents']['template']."</dt>\n";
				echo "<dd>".$display_template_choice."</dd>\n";
				echo "<dt>".$GLOBALS['lang']['contents']['visu1']."</dt>\n";
				echo "<dd>".$display_visual."</dd>\n";
			}
			echo "</dl>\n";
			?>
			<form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<?php echo cancel_button($cancel_link); ?>
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview'] ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>

==> dl.php?src=linea21_1_1.zip: linea21/contents/mod.php <==
<?php
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$complete_type=strtoupper($mod_inc);

$contents_object = new contents;

$mask_template=array_fill(1, 3, '');
$layer_tpl_1 = "style=\"display:block;\"";

if($type=='P') {
	$requete= SQL_getOnePublicationParts($id);
	$result=$sql_object->DBSelect($requete);
	$form_title=formatText($result[0]['publicon_title'],'2FIELD');
	$form_body=formatText($result[0]['publicon_body'],'2FIELD');
	$current_template=$result[0]['publicon_template'];
	$form_visual=$result[0]['publicon_photos_uri'];
	$reca_visual="<dl class=\"dl_mod\">\n";
	$reca_visual.="<dt>".$GLOBALS['lang']['contents']['visu1'].": </dt>\n";
	if(empty($result[0]['publicon_photos_uri'])) {
		$reca_visual.="<dd>".$GLOBALS['lang']['divers']['none']."</dd>\n";
		$reca_visual2=$GLOBALS['lang']['divers']['none'];
	} else {
		$complete_uri='../'.$result[0]['publicon_photos_uri'];
		list($width, $height, $type_img, $attr) = getimagesize($complete_uri);
		$reca_visual.='<dd>'.EnlargeImage($complete_uri)."</dd>\n";
		$reca_visual2=EnlargeImage($complete_uri);
	}
	$reca_visual.="</dl>\n";
	if(!isset($_POST['valider'])) $mask_template[$current_template]=' selected="selected"';
	if(!isset($_POST['valider']) && $result[0]['publicon_template']==3) $layer_tpl_1 = "style=\"display:none;\"";
	}
if($type=='W') {
	$requete= SQL_getOneWorkshopParts($id);
	$result=$sql_object->DBSelect($requete);
	$form_title=formatText($result[0]['workrepcon_title'], '2FIELD');
	$form_body=formatText($result[0]['workrepcon_body'], '2FIELD');
}



if(isset($_POST['enregistrer'])) {
	include_once('../class/system/class.upload.php');
	$upload_object= new upload;
	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$contents_object->ModifyContents($id, $data_table, $complete_type, $sql_object);
	if(isset($data_table[3])) $result_rename=$upload_object->Archivefile('../'.$data_table[3]);
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

if(isset($_POST['valider'])) {
	$table[0]=$_POST['part_title'];
	$table[1]=$_POST['part_body'];
	
	$integrity=$contents_object->CheckDataIntegrity($table,$type);
	
	if($type=='P') {
		$table[2]=$_POST['part_template'];
		$table[3]=isset($_FILES['visuel1']['name']) ? $_FILES['visuel1']['name'] : '' ;
		if(!is_string($integrity) && $_POST['current_template']==3 && ($_POST['part_template']==1 || $_POST['part_template']==2 ) && (!isset($_FILES['visuel1']) || $_FILES['visuel1']['name']=='' )) $integrity=$GLOBALS['lang']['contents']['no_visu1'];
			
	if(!is_string($integrity)) {
		if($_POST['part_template']!=3 && isset($_FILES['visuel1']['name']) && $_FILES['visuel1']['name']!='') {
			include_once('../class/system/class.upload.php');
			include_once('../class/system/class.image.php');
			$image_object = new image;
            $upload_object = new upload;
            $upload1 = $_FILES['visuel1'];
			$size_integrity=$upload_object->CheckMaxFile($upload1['size'], $contents_object->P_UPLOAD_MAX_MO);
			if(is_string($size_integrity)) $integrity=$size_integrity;
			$format_integrity=$upload_object->CheckExtImage($upload1['name']);
			if(is_string($format_integrity)) $integrity=$format_integrity;

			if(!is_string($integrity)) {
				$file_name=$id;
				$destination="../".$contents_object->P_URI_INPUT;
				$bdd_name=$file_name.".".$upload_object->GetExtension($upload1['name']);
				$final_name='temp_'.$bdd_name;
				$visual_link1=$destination.$final_name;
				$table[3]=$contents_object->P_URI_INPUT.$bdd_name;
				
				$result_upload=$upload_object->UploadFile($upload1, $final_name, $destination);
				
				// création des thumbs
				$min_name=get_min_name($destination.$final_name);
				$image_object->ThumbCreate($destination.$final_name, $min_name , $contents_object->P_MAX_PHOTO_MIN_WIDTH);
				
				// on retaille l'original au besoin.
				if(PHOTO_RESIZE===true && ExcedMaxSize($destination.$final_name, $contents_object->P_MAX_PHOTO_MAX_WIDTH)) {
					$image_object->ThumbCreate($destination.$final_name, $destination.$final_name , $contents_object->P_MAX_PHOTO_MAX_WIDTH);
				}
				
				// préparation de l'affichage de la miniature
				$visual_link1=EnlargeImage($visual_link1);
				
			}
        } else {
			if($_POST['part_template']!=3) $table[3]=$result[0]['publicon_photos_uri'];
			else $table[3]='';
		}
		}
	}

	
	if(is_string($integrity)) {
		$text_format='2FIELD';
	} else {
		$text_format='2HTML';
	}
	$form_title=formatText($_POST['part_title'], $text_format);
	$form_body=formatText($_POST['part_body'], $text_format);
	if($type=='P') {
		$mask_template[$_POST['part_template']]=' selected="selected"';
		if($_POST['part_template']==3) $layer_tpl_1 = "style=\"display:none;\"";
	}
	
	$table=urlencode(serialize($table));
}

if($type=='P') {
	$requete= SQL_getPublicationTitle($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['publi_title'], '2HTML');
	$current_owner=$result[0]['publi_posted_by'];
	
	//////////// Check Droits utilisateur ////////////
	if (GetSessionElement('id')!=$current_owner && !IsSuperAdmin()) ReloadIndex('admin');
	///////////

	
	// select-box Templates
	$select_template="<select name=\"part_template\" id=\"part_template\" onchange=\"ShowFilesLayer(this.value, 'contents')\">\n";
	$select_template.="<option value=\"1\"".$mask_template[1].">".$contents_object->GetTemplateName(1)."</option>\n";
	$select_template.="<option value=\"2\"".$mask_template[2].">".$contents_object->GetTemplateName(2)."</option>\n";
	$select_template.="<option value=\"3\"".$mask_template[3].">".$contents_object->GetTemplateName(3)."</option>\n";
	$select_template.="</select>\n";
}
if($type=='W') {
	$requete= SQL_getWorkshopRepTitleAndGroup($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['workrep_title'].' ('.$result[0]['workshop_denomination'].').', '2HTML');
	$current_workshop_id=$result[0]['workrep_workshop_id'];
	
	//////////// Check Droits utilisateur ////////////
	if (!AuthUser4Workshop($current_workshop_id, $sql_object) && !IsSuperAdmin()) ReloadIndex('admin');
	///////////
	
}
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu'][$mod_inc]; ?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($GLOBALS['lang']['contents'][$mod_inc.'_type']." : ". $current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>

<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
		?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
			<h2><? echo formatTitleh2($current_title); ?></h2>
			<form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post" enctype="multipart/form-data">
				<p>
				<label for="part_title"><? echo $GLOBALS['lang']['contents']['title']; ?> : *</label>
				<input name="part_title" type="text" class="textfield" id="part_title" maxlength="200" value="<?php echo $form_title; ?>" />
				</p>
				<p>
				<label for="part_body"><? echo $GLOBALS['lang']['contents']['body']; ?> : *</label>
				<textarea id="part_body" name="part_body" class="largetextfield" <?php echo AREA_SETTINGS; ?>><?php echo $form_body; ?></textarea>
				</p>
				<p>
				<?php  if($type=='P') { ?>
				<label for="part_template" ><? echo $GLOBALS['lang']['contents']['template']; ?> : *</label>
				<?php echo $select_template; ?>
				</p>
				<?php echo $reca_visual; ?>
				<p id="layervisuel1" <?php echo $layer_tpl_1; ?>>
					<label for="visuel1"><?php echo $GLOBALS['lang']['contents']['visu1']; ?></label>
					<input name="visuel1" type="file" size="47" id="visuel1"  class="file" /><br /><br />
				</p>
				<?php } ?>
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<input name="current_template" type="hidden" value="<?php echo $current_template; ?>" id="current_template" />
				<?php echo cancel_button($cancel_link); ?>
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Récapitulatif
} else	{

if($type=='P') {
	if($_POST['part_template']==3) {
		$display_visual=$GLOBALS['lang']['divers']['none'];
	} else {
		if(isset($visual_link1)) $display_visual=$visual_link1;
		else $display_visual=$reca_visual2;
	}
	$display_template_choice=$contents_object->GetTemplateName($_POST['part_template']);
}

?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
			<h2><? echo formatTitleh2($GLOBALS['lang']['recap']['title']); ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['contents']['title']."</dt>\n";
			echo "<dd>".$form_title."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['contents']['body']."</dt>\n";
			echo "<dd>".linkin_content($form_body)."</dd>\n";
			if($type=='P') {
				echo "<dt>".$GLOBALS['lang']['contents']['template']."</dt>\n";
				echo "<dd>".$display_template_choice."</dd>\n";
				echo "<dt>".$GLOBALS['lang']['contents']['visu1']."</dt>\n";
				echo "<dd>".$display_visual."</dd>\n";
			}
			echo "</dl>\n";
			?>
			<form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<?php echo cancel_button($cancel_link); ?>
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview'] ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>
